/* hello.c -- trivial test function for libfoo
   Copyright (C) 1996-1999 Free Software Foundation, Inc.
   This file is part of GNU Libtool.

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA. */

/* Written by Gordon Matzigkeit <gord@gnu.ai.mit.edu> */
#define _LIBFOO_COMPILATION
#include "foo.h"
#undef _LIBFOO_COMPILATION

#include <stdio.h>

int
hello ()
{
  printf ("** This is not GNU Hello.  There is no built-in mail reader. **\n");
  return HELLO_RET;
}
